@@ -128,7 +128,18 @@ class CfnProfilingGroup(
         :param tags: A list of tags to add to the created profiling group.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnProfilingGroup.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                profiling_group_name: builtins.str,
+                agent_permissions: typing.Any = None,
+                anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union["CfnProfilingGroup.ChannelProperty", typing.Dict[str, typing.Any]]]]]] = None,
+                compute_platform: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnProfilingGroupProps(
@@ -148,7 +159,9 @@ class CfnProfilingGroup(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnProfilingGroup.inspect)
+            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -161,7 +174,9 @@ class CfnProfilingGroup(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnProfilingGroup._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -212,7 +227,9 @@ class CfnProfilingGroup(
     @agent_permissions.setter
     def agent_permissions(self, value: typing.Any) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "agent_permissions").fset)
+            def stub(value: typing.Any) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "agentPermissions", value)
 
@@ -228,7 +245,9 @@ class CfnProfilingGroup(
     @profiling_group_name.setter
     def profiling_group_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "profiling_group_name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "profilingGroupName", value)
 
@@ -249,7 +268,11 @@ class CfnProfilingGroup(
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "anomaly_detection_notification_configuration").fset)
+            def stub(
+                value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnProfilingGroup.ChannelProperty"]]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
 
@@ -267,7 +290,9 @@ class CfnProfilingGroup(
     @compute_platform.setter
     def compute_platform(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "compute_platform").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "computePlatform", value)
 
@@ -307,7 +332,13 @@ class CfnProfilingGroup(
                 )
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(CfnProfilingGroup.ChannelProperty.__init__)
+                def stub(
+                    *,
+                    channel_uri: builtins.str,
+                    channel_id: typing.Optional[builtins.str] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument channel_uri", value=channel_uri, expected_type=type_hints["channel_uri"])
                 check_type(argname="argument channel_id", value=channel_id, expected_type=type_hints["channel_id"])
             self._values: typing.Dict[str, typing.Any] = {
@@ -406,7 +437,16 @@ class CfnProfilingGroupProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnProfilingGroupProps.__init__)
+            def stub(
+                *,
+                profiling_group_name: builtins.str,
+                agent_permissions: typing.Any = None,
+                anomaly_detection_notification_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[str, typing.Any]]]]]] = None,
+                compute_platform: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
             check_type(argname="argument agent_permissions", value=agent_permissions, expected_type=type_hints["agent_permissions"])
             check_type(argname="argument anomaly_detection_notification_configuration", value=anomaly_detection_notification_configuration, expected_type=type_hints["anomaly_detection_notification_configuration"])
@@ -585,7 +625,9 @@ class _IProfilingGroupProxy(
         :param grantee: Principal to grant publish rights to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IProfilingGroup.grant_publish)
+            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantPublish", [grantee]))
 
@@ -601,7 +643,9 @@ class _IProfilingGroupProxy(
         :param grantee: Principal to grant read rights to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IProfilingGroup.grant_read)
+            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantRead", [grantee]))
 
@@ -645,7 +689,15 @@ class ProfilingGroup(
         :param profiling_group_name: A name for the profiling group. Default: - automatically generated name.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                compute_platform: typing.Optional[ComputePlatform] = None,
+                profiling_group_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ProfilingGroupProps(
@@ -670,7 +722,13 @@ class ProfilingGroup(
         :param profiling_group_arn: Profiling Group ARN.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.from_profiling_group_arn)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                profiling_group_arn: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument profiling_group_arn", value=profiling_group_arn, expected_type=type_hints["profiling_group_arn"])
@@ -691,7 +749,13 @@ class ProfilingGroup(
         :param profiling_group_name: Profiling Group Name.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.from_profiling_group_name)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                profiling_group_name: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
@@ -712,7 +776,9 @@ class ProfilingGroup(
         :param grantee: Principal to grant publish rights to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.grant_publish)
+            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantPublish", [grantee]))
 
@@ -728,7 +794,9 @@ class ProfilingGroup(
         :param grantee: Principal to grant read rights to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.grant_read)
+            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantRead", [grantee]))
 
@@ -780,7 +848,13 @@ class ProfilingGroupProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroupProps.__init__)
+            def stub(
+                *,
+                compute_platform: typing.Optional[ComputePlatform] = None,
+                profiling_group_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument compute_platform", value=compute_platform, expected_type=type_hints["compute_platform"])
             check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
         self._values: typing.Dict[str, typing.Any] = {}
